==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mainmenu/translations/mainmenu_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>RazorMainMenu</name>
    <message>
        <location filename="../razormainmenu.cpp" line="178"/>
        <source>Leave</source>
        <translation>Verlassen</translation>
    </message>
</context>
<context>
    <name>RazorMainMenuConfiguration</name>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="14"/>
        <source>Razor Main Menu settings</source>
        <translation>Razor Hauptmenü Einstellungen</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Zeige Text</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="45"/>
        <source>Button text</source>
        <translation>Schaltflächen Text</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="65"/>
        <location filename="../razormainmenuconfiguration.ui" line="71"/>
        <source>Menu file</source>
        <translation>Menü Datei</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="85"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="95"/>
        <source>Keyboard Shortcut</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="101"/>
        <source>Click the button to record shortcut:</source>
        <translation>Klicke um Tastenkürzel zu ändern:</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.cpp" line="89"/>
        <source>Choose menu file</source>
        <translation>Wähle Menü Datei</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.cpp" line="89"/>
        <source>Menu files (*.menu)</source>
        <translation>Menü Datei (*.menu)</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mainmenu/translations/mainmenu_de_DE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de_DE" version="2.0">
<context>
    <name>RazorMainMenu</name>
    <message>
        <source>Leave</source>
        <translation>Verlassen</translation>
    </message>
</context>
<context>
    <name>RazorMainMenuConfiguration</name>
    <message>
        <source>Razor Main Menu settings</source>
        <translation>Razor Hauptmenü Einstellungen</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation>Zeige Text</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation>Schaltflächen Text</translation>
    </message>
    <message>
        <source>Menu file</source>
        <translation>Menü Datei</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Keyboard Shortcut</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <source>Click the button to record shortcut:</source>
        <translation>Klicke um Tastenkürzel zu ändern:</translation>
    </message>
    <message>
        <source>Choose menu file</source>
        <translation>Wähle Menü Datei</translation>
    </message>
    <message>
        <source>Menu files (*.menu)</source>
        <translation>Menü Datei (*.menu)</translation>
    </message>
</context>
</TS>
